@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010 Sebastian Wiesner <lunaryorn@googlemail.com>
+# Copyright (C) 2010 Sebastian Wiesner <lunaryorn@googlemail.com>
 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# This library is free software; you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the
+# Free Software Foundation; either version 2.1 of the License, or (at your
+# option) any later version.
 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This library is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+# for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this library; if not, write to the Free Software Foundation,
+# Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 
 """
@@ -88,6 +87,7 @@ SIGNATURES = {
         unref=([udev_enumerate_p], None),
         add_match_subsystem=([udev_enumerate_p, c_char_p], int),
         add_match_property=([udev_enumerate_p, c_char_p, c_char_p], int),
+        add_match_tag=([udev_enumerate_p, c_char_p], int),
         scan_devices=([udev_enumerate_p], int),
         get_list_entry=([udev_enumerate_p], udev_list_entry_p)),
     # list entries
@@ -102,6 +102,7 @@ SIGNATURES = {
         new_from_syspath=([udev_p, c_char_p], udev_device_p),
         new_from_subsystem_sysname=([udev_p, c_char_p, c_char_p],
                                     udev_device_p),
+        new_from_environment=([udev_p], udev_device_p),
         get_parent=([udev_device_p], udev_device_p),
         get_devpath=([udev_device_p], c_char_p),
         get_subsystem=([udev_device_p], c_char_p),
@@ -113,6 +114,7 @@ SIGNATURES = {
         get_sysattr_value=([udev_device_p, c_char_p], c_char_p),
         get_action=([udev_device_p], c_char_p),
         get_devlinks_list_entry=([udev_device_p], udev_list_entry_p),
+        get_tags_list_entry=([udev_device_p], udev_list_entry_p),
         get_properties_list_entry=([udev_device_p], udev_list_entry_p)),
     # monitoring
     'udev_monitor': dict(
@@ -138,8 +140,8 @@ def load_udev_library():
     """
     libudev = CDLL(find_library('udev'), use_errno=True)
     # context function signature
-    for namespace, members in SIGNATURES.iteritems():
-        for funcname, signature in members.iteritems():
+    for namespace, members in SIGNATURES.items():
+        for funcname, signature in members.items():
             funcname = '{0}_{1}'.format(namespace, funcname)
             func = getattr(libudev, funcname)
             argtypes, restype = signature
