@@ -94,6 +94,10 @@ def test_device_from_name_nonexisting_subsystem(context):
         error.sys_name, error.subsystem)
 
 
+def test_device_from_environment(context):
+    raise NotImplementedError()
+
+
 @py.test.mark.properties
 def test_device_properties(device, properties):
     properties.pop('DEVNAME', None)
@@ -227,6 +231,10 @@ def test_device_links(context, device, device_links):
     assert all(py.test.is_unicode_string(l) for l in device.device_links)
 
 
+def test_device_tags():
+    raise NotImplementedError()
+
+
 @py.test.mark.properties
 def test_device_driver(device, properties):
     if 'DRIVER' in properties:
